@@ -30,7 +30,9 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -82,6 +84,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  backend="auto",
                  gpuId=None,
                  interactionConstraints=None,
+                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
